@@ -2,19 +2,22 @@ mod constraint_manager;
 pub use constraint_manager::ConstraintManager;
 pub use constraint_manager::ConstraintManagerError;
 
-mod encoded_size;
-pub use encoded_size::ConstEncodedSize;
-pub use encoded_size::EncodedSize;
-pub use encoded_size::SelfEncodedSize;
+mod format_traits;
+pub use format_traits::ConstEncodedSize;
+pub use format_traits::EncodedSize;
+pub use format_traits::SelfEncodedSize;
 
 mod index_formats;
 
 mod index_manager;
 pub use index_manager::IndexManager;
 
-mod io_manager;
-pub use io_manager::IOManager;
-pub use io_manager::IOManagerError;
+mod file_manager;
+pub use file_manager::FileManager;
+pub use file_manager::FileManagerError;
+
+mod lock_manager;
+//pub use lock_manager::LockManager;
 
 mod page_formats;
 
