@@ -6,6 +6,10 @@ mod page_data;
 pub use page_data::PageData;
 pub use page_data::PageDataError;
 
+mod page_offset;
+pub use page_offset::PageOffset;
+pub use page_offset::PageOffsetError;
+
 mod page_header;
 pub use page_header::PageHeader;
 pub use page_header::PageHeaderError;
