@@ -1,20 +1,22 @@
-use crate::engine::io::EncodedSize;
+use crate::constants::PAGE_SIZE;
+use crate::engine::io::{ConstEncodedSize, EncodedSize};
 use crate::engine::objects::SqlTuple;
 use crate::engine::transactions::TransactionId;
 
 use super::super::super::objects::Table;
 use super::super::row_formats::{ItemPointer, RowData, RowDataError};
-use super::{ItemIdData, ItemIdDataError, PageHeader, PageHeaderError, UInt12, UInt12Error};
+use super::{
+    ItemIdData, ItemIdDataError, PageHeader, PageHeaderError, PageOffset, UInt12, UInt12Error,
+};
 use async_stream::stream;
-use bytes::{BufMut, Bytes, BytesMut};
+use bytes::{Bytes, BytesMut};
 use futures::stream::Stream;
 use std::convert::TryFrom;
-use std::mem;
 use std::sync::Arc;
 use thiserror::Error;
 
 pub struct PageData {
-    page: usize,
+    page: PageOffset,
     page_header: PageHeader,
     item_ids: Vec<ItemIdData>,
     //TODO debating if I should defer parsing until later
@@ -22,7 +24,7 @@ pub struct PageData {
 }
 
 impl PageData {
-    pub fn new(page: usize) -> PageData {
+    pub fn new(page: PageOffset) -> PageData {
         PageData {
             page,
             page_header: PageHeader::new(),
@@ -59,7 +61,7 @@ impl PageData {
     }
 
     pub fn update(&mut self, row_data: RowData, row_count: UInt12) -> Result<(), PageDataError> {
-        let row_data_len = row_data.serialize().len();
+        let row_data_len = RowData::encoded_size(&row_data.user_data);
         let row_count = row_count.to_usize();
         if row_count > self.item_ids.len() - 1 || row_count > self.rows.len() - 1 {
             return Err(PageDataError::IndexOutofBounds(
@@ -95,40 +97,42 @@ impl PageData {
     }
 
     pub fn serialize(&self) -> Bytes {
-        let mut buffer = BytesMut::with_capacity((UInt12::max().to_u16() + 1).into());
+        let mut buffer = BytesMut::with_capacity(PAGE_SIZE as usize);
 
-        buffer.put(self.page_header.serialize());
+        self.page_header.serialize(&mut buffer);
 
         //Now write items data in order
-        for item in self.item_ids.iter() {
-            buffer.put(item.serialize());
-        }
+        self.item_ids.iter().for_each(|f| f.serialize(&mut buffer));
 
         //Fill the free space
         let free_space = vec![0; self.page_header.get_free_space()];
         buffer.extend_from_slice(&free_space);
 
         //Write items in reverse order
-        for value in self.rows.iter().rev() {
-            buffer.put(value.serialize());
-        }
+        self.rows
+            .iter()
+            .rev()
+            .for_each(|r| r.serialize(&mut buffer));
 
         buffer.freeze()
     }
 
-    pub fn parse(table: Arc<Table>, page: usize, buffer: Bytes) -> Result<PageData, PageDataError> {
+    pub fn parse(
+        table: Arc<Table>,
+        page: PageOffset,
+        buffer: Bytes,
+    ) -> Result<PageData, PageDataError> {
         //Note since we need random access, everything MUST work off slices otherwise counts will be off
 
-        let mut page_header_slice = buffer.slice(0..mem::size_of::<PageHeader>());
+        let mut page_header_slice = buffer.slice(0..PageHeader::encoded_size());
         let page_header = PageHeader::parse(&mut page_header_slice)?;
 
         let mut item_ids: Vec<ItemIdData> = Vec::with_capacity(page_header.get_item_count());
         let mut rows: Vec<RowData> = Vec::with_capacity(page_header.get_item_count());
         for i in 0..page_header.get_item_count() {
-            let iid_lower_offset =
-                mem::size_of::<PageHeader>() + (ItemIdData::serialize_size() * i);
+            let iid_lower_offset = PageHeader::encoded_size() + (ItemIdData::encoded_size() * i);
             let iid_upper_offset =
-                mem::size_of::<PageHeader>() + (ItemIdData::serialize_size() * (i + 1));
+                PageHeader::encoded_size() + (ItemIdData::encoded_size() * (i + 1));
             let mut iid_slice = buffer.slice(iid_lower_offset..iid_upper_offset);
             let iid = ItemIdData::parse(&mut iid_slice)?;
 
@@ -177,17 +181,10 @@ mod tests {
     use super::super::super::super::transactions::TransactionId;
     use super::*;
     use futures::pin_mut;
-    use futures::stream::StreamExt;
-
-    //Async testing help can be found here: https://blog.x5ff.xyz/blog/async-tests-tokio-rust/
-    macro_rules! aw {
-        ($e:expr) => {
-            tokio_test::block_on($e)
-        };
-    }
+    use tokio_stream::StreamExt;
 
     fn get_item_pointer(row_num: usize) -> ItemPointer {
-        ItemPointer::new(0, UInt12::new(row_num as u16).unwrap())
+        ItemPointer::new(PageOffset(0), UInt12::new(row_num as u16).unwrap())
     }
 
     fn get_table() -> Arc<Table> {
@@ -217,8 +214,8 @@ mod tests {
         ))
     }
 
-    #[test]
-    fn test_page_data_roundtrip() -> Result<(), Box<dyn std::error::Error>> {
+    #[tokio::test]
+    async fn test_page_data_roundtrip() -> Result<(), Box<dyn std::error::Error>> {
         let table = get_table();
 
         let rows = vec!(RowData::new(table.sql_type.clone(),
@@ -232,22 +229,24 @@ mod tests {
             ]),
         ));
 
-        let mut pd = PageData::new(0);
+        let mut pd = PageData::new(PageOffset(0));
         for r in rows.clone() {
             assert!(pd.insert(r.min, &table, r.user_data).is_ok());
         }
         let serial = pd.serialize();
-        let pg_parsed = PageData::parse(table.clone(), 0, serial).unwrap();
+
+        assert_eq!(PAGE_SIZE as usize, serial.len());
+        let pg_parsed = PageData::parse(table.clone(), PageOffset(0), serial).unwrap();
 
         pin_mut!(pg_parsed);
-        let result_rows: Vec<RowData> = aw!(pg_parsed.get_stream().collect());
+        let result_rows: Vec<RowData> = pg_parsed.get_stream().collect().await;
         assert_eq!(rows, result_rows);
 
         Ok(())
     }
 
-    #[test]
-    fn test_page_data_roundtrip_two_rows() {
+    #[tokio::test]
+    async fn test_page_data_roundtrip_two_rows() {
         let table = get_table();
 
         let rows = vec!(RowData::new(table.sql_type.clone(),
@@ -270,20 +269,20 @@ mod tests {
         ]),
         ));
 
-        let mut pd = PageData::new(0);
+        let mut pd = PageData::new(PageOffset(0));
         for r in rows.clone() {
             assert!(pd.insert(r.min, &table, r.user_data).is_ok());
         }
         let serial = pd.serialize();
-        let pg_parsed = PageData::parse(table.clone(), 0, serial).unwrap();
+        let pg_parsed = PageData::parse(table.clone(), PageOffset(0), serial).unwrap();
 
         pin_mut!(pg_parsed);
-        let result_rows: Vec<RowData> = aw!(pg_parsed.get_stream().collect());
+        let result_rows: Vec<RowData> = pg_parsed.get_stream().collect().await;
         assert_eq!(rows, result_rows);
     }
 
-    #[test]
-    fn test_page_data_update() {
+    #[tokio::test]
+    async fn test_page_data_update() {
         let table = get_table();
 
         let mut row = RowData::new(table.sql_type.clone(),
@@ -297,7 +296,7 @@ mod tests {
             ]),
         );
 
-        let mut pd = PageData::new(0);
+        let mut pd = PageData::new(PageOffset(0));
         let rip = pd.insert(row.min, &table, row.user_data.clone());
         assert!(rip.is_ok());
 
@@ -308,7 +307,7 @@ mod tests {
         assert!(pd.update(row.clone(), ip.count).is_ok());
 
         pin_mut!(pd);
-        let result_rows: Vec<RowData> = aw!(pd.get_stream().collect());
+        let result_rows: Vec<RowData> = pd.get_stream().collect().await;
         assert_eq!(row, result_rows[0]);
     }
 }
