@@ -1,16 +1,14 @@
 //We are only going to support 4kb pages to match most common underlying I/O subsystems
-use bytes::{Buf, BufMut, Bytes, BytesMut};
+use bytes::{Buf, BufMut};
 use std::convert::TryFrom;
 use std::fmt;
-use std::mem;
 use std::mem::size_of;
 use std::ops::{Add, AddAssign, Sub, SubAssign};
 use thiserror::Error;
 
+use crate::constants::PAGE_SIZE;
 use crate::engine::io::ConstEncodedSize;
 
-const PAGE_SIZE: u16 = 4096;
-
 #[derive(Copy, Clone, Debug, PartialEq, PartialOrd)]
 pub struct UInt12(u16);
 
@@ -35,11 +33,11 @@ impl UInt12 {
         }
     }
 
-    pub fn to_u16(&self) -> u16 {
+    pub fn to_u16(self) -> u16 {
         self.0
     }
 
-    pub fn to_usize(&self) -> usize {
+    pub fn to_usize(self) -> usize {
         usize::try_from(self.0).unwrap()
     }
 
@@ -47,22 +45,64 @@ impl UInt12 {
         UInt12(PAGE_SIZE - 1)
     }
 
-    pub fn serialize(&self) -> Bytes {
-        let mut buf = BytesMut::with_capacity(mem::size_of::<u16>());
-        buf.put_u16_le(self.0);
-        buf.freeze()
-    }
+    pub fn serialize_packed(buffer: &mut impl BufMut, args: &[UInt12]) {
+        let mut left = true;
+        let mut combined = None;
 
-    pub fn parse(buffer: &mut impl Buf) -> Result<Self, UInt12Error> {
-        if buffer.remaining() < mem::size_of::<u16>() {
-            return Err(UInt12Error::InsufficentData(buffer.remaining()));
+        for a in args {
+            if left {
+                buffer.put_u8((a.to_u16() & 0x00FF) as u8);
+                combined = Some(((a.to_u16() & 0xFF00) >> 4) as u8);
+                left = false;
+            } else {
+                buffer.put_u8(combined.unwrap() | ((a.to_u16() & 0xFF00) >> 8) as u8);
+                buffer.put_u8((a.to_u16() & 0x00FF) as u8);
+                combined = None;
+                left = true;
+            }
         }
 
-        let raw_value = buffer.get_u16_le();
+        if let Some(s) = combined {
+            buffer.put_u8(s)
+        }
+    }
 
-        let value = UInt12::new(raw_value)?;
+    pub fn parse_packed(
+        buffer: &mut impl Buf,
+        expected_count: usize,
+    ) -> Result<Vec<UInt12>, UInt12Error> {
+        let mut items = Vec::with_capacity(expected_count);
+        let mut count = 0;
 
-        Ok(value)
+        let mut left: u16 = 0;
+        let mut middle: u16 = 0;
+
+        while items.len() < expected_count {
+            if !buffer.has_remaining() {
+                return Err(UInt12Error::InsufficentData(buffer.remaining()));
+            }
+
+            match count % 3 {
+                0 => {
+                    left = buffer.get_u8() as u16;
+                }
+                1 => {
+                    middle = buffer.get_u8() as u16;
+                    let item = UInt12::new(left | (middle & 0x00F0) << 4)?;
+                    items.push(item);
+                }
+                2 => {
+                    let right = buffer.get_u8() as u16;
+                    let item = UInt12::new(right | (middle & 0x000F) << 8)?;
+                    items.push(item);
+                }
+                _ => panic!("Modular math is broken."),
+            }
+
+            count += 1;
+        }
+
+        Ok(items)
     }
 }
 
@@ -130,6 +170,8 @@ pub enum UInt12Error {
 
 #[cfg(test)]
 mod tests {
+    use bytes::BytesMut;
+
     use super::*;
 
     #[test]
@@ -182,4 +224,33 @@ mod tests {
 
         assert!(test.is_err());
     }
+
+    fn roundtrip(input: Vec<UInt12>, serial_len: usize) -> Result<(), Box<dyn std::error::Error>> {
+        let mut buffer = BytesMut::new();
+        UInt12::serialize_packed(&mut buffer, &input);
+        let mut buffer = buffer.freeze();
+        assert_eq!(buffer.len(), serial_len);
+        let test_rt = UInt12::parse_packed(&mut buffer, input.len())?;
+        assert_eq!(test_rt, input);
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_roundtrip() -> Result<(), Box<dyn std::error::Error>> {
+        //Value that gave me a lovely bug
+        roundtrip(vec![UInt12::new(0)?], 2)?;
+
+        //Test numbers were picked to give a distingishable binary pattern for troubleshooting
+        roundtrip(vec![UInt12::new(2730)?], 2)?;
+
+        roundtrip(vec![UInt12::new(2730)?, UInt12::new(1365)?], 3)?;
+
+        roundtrip(
+            vec![UInt12::new(2730)?, UInt12::new(1365)?, UInt12::new(2730)?],
+            5,
+        )?;
+
+        Ok(())
+    }
 }
