@@ -3,6 +3,7 @@
 //!
 //! We will be treating this a little different since our size will be based on usize
 
+use crate::engine::io::page_formats::PageOffset;
 use crate::engine::io::ConstEncodedSize;
 
 use super::super::page_formats::{UInt12, UInt12Error};
@@ -15,20 +16,20 @@ use thiserror::Error;
 
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub struct ItemPointer {
-    pub page: usize,
+    pub page: PageOffset,
     pub count: UInt12,
 }
 
 impl ItemPointer {
-    pub fn new(page: usize, count: UInt12) -> ItemPointer {
+    pub fn new(page: PageOffset, count: UInt12) -> ItemPointer {
         ItemPointer { page, count }
     }
 
     pub fn serialize(&self) -> Bytes {
         let mut buffer = BytesMut::with_capacity(size_of::<ItemPointer>());
 
-        buffer.put_slice(&self.page.to_le_bytes());
-        buffer.put(self.count.serialize());
+        buffer.put_slice(&self.page.0.to_le_bytes());
+        UInt12::serialize_packed(&mut buffer, &[self.count]);
 
         buffer.freeze()
     }
@@ -44,16 +45,16 @@ impl ItemPointer {
         let value = buffer.get_uint_le(size_of::<usize>());
         let page = usize::try_from(value)?;
 
-        let count = UInt12::parse(buffer)?;
-        Ok(ItemPointer::new(page, count))
+        let items = UInt12::parse_packed(buffer, 1)?;
+        Ok(ItemPointer::new(PageOffset(page), items[0]))
     }
 }
 
 impl fmt::Display for ItemPointer {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "\tItemPointer\n")?;
-        write!(f, "\tPage: {}\n", self.page)?;
-        write!(f, "\tCount: {}\n", self.count)
+        writeln!(f, "\tItemPointer")?;
+        writeln!(f, "\tPage: {}", self.page)?;
+        writeln!(f, "\tCount: {}", self.count)
     }
 }
 
@@ -81,14 +82,11 @@ mod tests {
 
     #[test]
     fn test_item_pointer_roundtrip() -> Result<(), Box<dyn std::error::Error>> {
-        let test = ItemPointer::new(1, UInt12::new(1).unwrap());
+        let test = ItemPointer::new(PageOffset(1), UInt12::new(1).unwrap());
 
         let mut test_serial = test.clone().serialize();
         let test_reparse = ItemPointer::parse(&mut test_serial)?;
 
-        //Smoke test display
-        println!("{}", test_reparse);
-
         assert_eq!(test, test_reparse);
         Ok(())
     }
@@ -106,7 +104,7 @@ mod tests {
 
         assert_eq!(
             Err(ItemPointerError::UInt12Error(UInt12Error::InsufficentData(
-                1
+                0
             ))),
             parse
         );
