@@ -7,13 +7,28 @@ use thiserror::Error;
 pub struct NullMask {}
 
 impl NullMask {
-    pub fn serialize(input: &SqlTuple, none_null_empty: bool) -> Bytes {
-        if input.0.len() == 0 {
+    /// Writes out a bit vector that sets a bit for every null value.
+    ///
+    /// # Examples
+    /// ```
+    /// # use feophantlib::engine::{io::row_formats::NullMask, objects::{SqlTuple, types::BaseSqlTypes}};
+    /// # use hex_literal::hex;
+    /// # use bytes::Bytes;
+    ///
+    /// let test = SqlTuple(vec![Some(BaseSqlTypes::Bool(true)),
+    ///     Some(BaseSqlTypes::Bool(true)),
+    ///     Some(BaseSqlTypes::Bool(true)),
+    ///     ]);
+    ///
+    /// let mask = NullMask::serialize(&test);
+    /// assert_eq!(hex!("00").to_vec(), mask);
+    /// ```
+    pub fn serialize(input: &SqlTuple) -> Bytes {
+        if input.0.is_empty() {
             return Bytes::new();
         }
 
         let mut buffer = BytesMut::new();
-        let mut any_null = false;
 
         let mut value: u8 = 0;
         let mut mask: u8 = 0x80;
@@ -21,7 +36,6 @@ impl NullMask {
         loop {
             if input.0[i].is_none() {
                 value |= mask;
-                any_null = true;
             }
 
             if (i + 1) == input.0.len() {
@@ -42,14 +56,11 @@ impl NullMask {
             i += 1;
         }
 
-        if !any_null && none_null_empty {
-            return Bytes::new();
-        }
         buffer.freeze()
     }
 
     pub fn parse(buffer: &mut impl Buf, column_count: usize) -> Result<Vec<bool>, NullMaskError> {
-        let mut nulls = vec![];
+        let mut nulls = Vec::with_capacity(((column_count + 7) / 8) * 8);
 
         if buffer.remaining() <= column_count / 8 {
             return Err(NullMaskError::BufferTooShort(
@@ -124,7 +135,7 @@ mod tests {
     fn test_null_mask_serialize() {
         let test = get_tuple();
 
-        let result = NullMask::serialize(&test, true);
+        let result = NullMask::serialize(&test);
 
         assert_eq!(hex!("aa 80").to_vec(), result.to_vec());
     }
@@ -133,24 +144,11 @@ mod tests {
     fn test_null_mask_single() {
         let test = SqlTuple(vec![None]);
 
-        let result = NullMask::serialize(&test, true);
+        let result = NullMask::serialize(&test);
 
         assert_eq!(hex!("80").to_vec(), result.to_vec());
     }
 
-    #[test]
-    fn test_null_mask_all_false() {
-        let test = SqlTuple(vec![
-            Some(BaseSqlTypes::Bool(true)),
-            Some(BaseSqlTypes::Bool(true)),
-            Some(BaseSqlTypes::Bool(true)),
-        ]);
-
-        let result = NullMask::serialize(&test, true);
-
-        assert_eq!(Bytes::new(), result);
-    }
-
     #[test]
     fn test_null_mask_parse() -> Result<(), Box<dyn std::error::Error>> {
         let test = vec![
@@ -178,7 +176,7 @@ mod tests {
             true, false, true, false, true, false, true, false, true, false, false, false,
         ];
 
-        let mut result = NullMask::serialize(&test, true);
+        let mut result = NullMask::serialize(&test);
         assert_eq!(Bytes::from_static(&hex!("aa 80")), result);
         let parse = NullMask::parse(&mut result, 12)?;
 
@@ -186,24 +184,6 @@ mod tests {
         Ok(())
     }
 
-    #[test]
-    fn test_null_mask_preserve() -> Result<(), Box<dyn std::error::Error>> {
-        let all_null = SqlTuple(vec![
-            Some(BaseSqlTypes::Bool(true)),
-            Some(BaseSqlTypes::Bool(true)),
-        ]);
-
-        let no_preserve = Bytes::from_static(&[]);
-        let result = NullMask::serialize(&all_null, true);
-        assert_eq!(no_preserve, result);
-
-        let preserve = Bytes::from_static(&[0]);
-        let result = NullMask::serialize(&all_null, false);
-        assert_eq!(preserve, result);
-
-        Ok(())
-    }
-
     #[test]
     fn test_encoded_size() {
         assert_eq!(2, NullMask::encoded_size(&get_tuple()));
