@@ -1,16 +1,14 @@
 //! Encodes / decodes a row into a byte array based on the supplied specification
 //! Format from here: https://www.postgresql.org/docs/current/storage-page-layout.html
 //! As always I'm only implementing what I need and will extend once I need more
-use crate::engine::io::{ConstEncodedSize, EncodedSize, SelfEncodedSize};
-use crate::engine::objects::types::{BaseSqlTypes, BaseSqlTypesError, SqlTypeDefinition};
-use crate::engine::objects::SqlTuple;
-
-use super::super::super::super::constants::{BuiltinSqlTypes, DeserializeTypes};
 use super::super::super::objects::Table;
 use super::super::super::transactions::TransactionId;
 use super::null_mask::NullMaskError;
 use super::{InfoMask, ItemPointer, ItemPointerError, NullMask};
-use bytes::{Buf, BufMut, Bytes, BytesMut};
+use crate::engine::io::{ConstEncodedSize, EncodedSize, SelfEncodedSize};
+use crate::engine::objects::types::{BaseSqlTypes, BaseSqlTypesError, SqlTypeDefinition};
+use crate::engine::objects::SqlTuple;
+use bytes::{Buf, BufMut};
 use std::fmt;
 use std::mem::size_of;
 use std::sync::Arc;
@@ -59,44 +57,31 @@ impl RowData {
     }
 
     pub fn get_column_not_null(&self, name: &str) -> Result<BaseSqlTypes, RowDataError> {
-        Ok(self
-            .get_column(name)?
-            .ok_or_else(|| RowDataError::UnexpectedNull(name.to_string()))?)
+        self.get_column(name)?
+            .ok_or_else(|| RowDataError::UnexpectedNull(name.to_string()))
     }
 
-    pub fn serialize(&self) -> Bytes {
-        let mut buffer = BytesMut::new();
+    pub fn serialize(&self, buffer: &mut impl BufMut) {
         buffer.put_u64_le(self.min.get_u64());
-        buffer.put_u64_le(self.max.unwrap_or(TransactionId::new(0)).get_u64());
+        buffer.put_u64_le(self.max.unwrap_or_else(|| TransactionId::new(0)).get_u64());
 
         buffer.put(self.item_pointer.serialize());
 
+        //If there is null we add it to the flags and write a nullmask
         let mut mask = InfoMask::empty();
-        for i in self.user_data.0.iter() {
-            match i {
-                Some(_) => {}
-                None => {
-                    mask = InfoMask::HAS_NULL;
-                }
-            }
-        }
-        buffer.put_u8(mask.bits());
-
-        let nulls = NullMask::serialize(&self.user_data, true);
-        buffer.put(nulls);
-
-        for data in &self.user_data.0 {
-            match data {
-                Some(d) => d.serialize(&mut buffer),
-                None => {}
-            }
+        if self.user_data.iter().any(|x| x.is_none()) {
+            mask = InfoMask::HAS_NULL;
+            buffer.put_u8(mask.bits());
+            buffer.put(NullMask::serialize(&self.user_data));
+        } else {
+            buffer.put_u8(mask.bits());
         }
 
-        buffer.freeze()
+        self.user_data.serialize(buffer);
     }
 
     pub fn parse(table: Arc<Table>, row_buffer: &mut impl Buf) -> Result<RowData, RowDataError> {
-        if row_buffer.remaining() < size_of::<TransactionId>() {
+        if row_buffer.remaining() < TransactionId::encoded_size() {
             return Err(RowDataError::MissingMinData(
                 size_of::<TransactionId>(),
                 row_buffer.remaining(),
@@ -104,7 +89,7 @@ impl RowData {
         }
         let min = TransactionId::new(row_buffer.get_u64_le());
 
-        if row_buffer.remaining() < size_of::<TransactionId>() {
+        if row_buffer.remaining() < TransactionId::encoded_size() {
             return Err(RowDataError::MissingMaxData(
                 size_of::<TransactionId>(),
                 row_buffer.remaining(),
@@ -173,18 +158,18 @@ impl RowData {
 
 impl fmt::Display for RowData {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        write!(f, "RowData\n")?;
-        write!(f, "\tType: {}\n", self.sql_type)?;
-        write!(f, "\tMin Tran: {}\n", self.min)?;
+        writeln!(f, "RowData")?;
+        writeln!(f, "\tType: {}", self.sql_type)?;
+        writeln!(f, "\tMin Tran: {}", self.min)?;
         match self.max {
-            Some(m) => write!(f, "\tMax Tran: {}\n", m),
-            None => write!(f, "\tMax Tran: Unset\n"),
+            Some(m) => writeln!(f, "\tMax Tran: {}", m),
+            None => writeln!(f, "\tMax Tran: Unset"),
         }?;
-        write!(f, "\t{}\n", self.item_pointer)?;
+        writeln!(f, "\t{}", self.item_pointer)?;
         for column in &self.user_data.0 {
             match column {
-                Some(c) => write!(f, "\t{}\n", c),
-                None => write!(f, "\tNull\n"),
+                Some(c) => writeln!(f, "\t{}", c),
+                None => writeln!(f, "\tNull"),
             }?;
         }
         Ok(())
@@ -198,10 +183,7 @@ impl EncodedSize<&SqlTuple> for RowData {
             + ItemPointer::encoded_size()
             + InfoMask::encoded_size()
             + NullMask::encoded_size(input)
-            + input.iter().fold(0, |acc, col| match col {
-                Some(col_s) => acc + col_s.encoded_size(),
-                None => acc,
-            })
+            + input.encoded_size()
     }
 }
 
@@ -211,8 +193,6 @@ pub enum RowDataError {
     BaseSqlTypes(#[from] BaseSqlTypesError),
     #[error("Table definition length {0} does not match columns passed {1}")]
     TableRowSizeMismatch(usize, usize),
-    #[error("Table definition type {0} does not match column passed {1}")]
-    TableRowTypeMismatch(BuiltinSqlTypes, DeserializeTypes),
     #[error("Not enough min data need {0} got {1}")]
     MissingMinData(usize, usize),
     #[error("Not enough max data need {0} got {1}")]
@@ -233,7 +213,10 @@ pub enum RowDataError {
 
 #[cfg(test)]
 mod tests {
+    use bytes::BytesMut;
+
     use crate::constants::Nullable;
+    use crate::engine::io::page_formats::PageOffset;
     use crate::engine::objects::types::BaseSqlTypesMapper;
 
     use super::super::super::super::objects::Attribute;
@@ -241,7 +224,7 @@ mod tests {
     use super::*;
 
     fn get_item_pointer() -> ItemPointer {
-        ItemPointer::new(0, UInt12::new(0).unwrap())
+        ItemPointer::new(PageOffset(0), UInt12::new(0).unwrap())
     }
 
     #[test]
@@ -265,8 +248,11 @@ mod tests {
             SqlTuple(vec![Some(BaseSqlTypes::Text("this is a test".to_string()))]),
         );
 
-        let mut test_serial = test.serialize();
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse);
 
         Ok(())
@@ -304,8 +290,11 @@ mod tests {
             ]),
         );
 
-        let mut test_serial = test.serialize();
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse);
 
         Ok(())
@@ -332,8 +321,11 @@ mod tests {
             SqlTuple(vec![Some(BaseSqlTypes::Uuid(uuid::Uuid::new_v4()))]),
         );
 
-        let mut test_serial = test.serialize();
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse);
 
         Ok(())
@@ -371,8 +363,11 @@ mod tests {
             ]),
         );
 
-        let mut test_serial = test.serialize();
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse);
 
         Ok(())
@@ -407,9 +402,12 @@ mod tests {
             SqlTuple(vec![Some(BaseSqlTypes::Uuid(uuid::Uuid::new_v4())), None]),
         );
 
-        let mut test_serial = test.serialize();
-        println!("{:?}", test_serial.len());
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        println!("{:?}", buffer.len());
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse);
 
         Ok(())
@@ -453,8 +451,11 @@ mod tests {
             ]),
         );
 
-        let mut test_serial = test.serialize();
-        let test_parse = RowData::parse(table, &mut test_serial)?;
+        let mut buffer = BytesMut::new();
+        test.serialize(&mut buffer);
+        let mut buffer = buffer.freeze();
+
+        let test_parse = RowData::parse(table, &mut buffer)?;
         assert_eq!(test, test_parse.clone());
 
         let column_val = test_parse.get_column_not_null("header")?;
